Enum rustc_mir::interpret::Place
[−]
[src]
pub enum Place {
Ptr {
ptr: PtrAndAlign,
extra: PlaceExtra,
},
Local {
frame: usize,
local: Local,
},
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
Ptr🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An place referring to a value allocated in the Memory system.
Fields of Ptr
ptr: PtrAndAlign | 🔬 This is a nightly-only experimental API. ( |
extra: PlaceExtra | 🔬 This is a nightly-only experimental API. ( |
Local🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An place referring to a value on the stack. Represented by a stack frame index paired with a Mir local index.
Fields of Local
frame: usize | 🔬 This is a nightly-only experimental API. ( |
local: Local | 🔬 This is a nightly-only experimental API. ( |
Methods
impl<'tcx> Place[src]
pub fn undef() -> Self[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Produces an Place that will error if attempted to be read from
pub fn from_primval_ptr(ptr: Pointer) -> Self[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn from_ptr(ptr: MemoryPointer) -> Self[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr_extra_aligned(self) -> (PtrAndAlign, PlaceExtra)[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn to_ptr(self) -> EvalResult<'tcx, MemoryPointer>[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?