Enum rustc_mir::interpret::StackPopCleanup
[−]
[src]
pub enum StackPopCleanup {
MarkStatic(Mutability),
Goto(BasicBlock),
None,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Variants
MarkStatic(Mutability)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The stackframe existed to compute the initial value of a static/constant, make sure it
isn't modifyable afterwards in case of constants.
In case of static mut, mark the memory to ensure it's never marked as immutable through
references or deallocated
Goto(BasicBlock)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A regular stackframe added due to a function call will need to get forwarded to the next block
None🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The main function and diverging functions have nowhere to return to